<?php
/**
 * Third Eye Theme Customizer
 *
 * @package Third_Eye
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function third_eye_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector'        => '.site-title a',
			'render_callback' => 'third_eye_customize_partial_blogname',
		) );
		$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
			'selector'        => '.site-description',
			'render_callback' => 'third_eye_customize_partial_blogdescription',
		) );
	}

	// Home image text
     $wp_customize->add_setting('third_eye_header_img_show', array(
        'capability'     => 'edit_theme_options',
        'type'           => 'theme_mod',
        'default'       =>  0,
        'sanitize_callback' => 'absint',
         'transport' => 'refresh',

    ));
    $wp_customize->add_control('third_eye_header_img_show_control', array(
        'label'      => __('Display header banner', 'third-eye'),
        'description'     => __('You can show or hide header image by this checkbox. You will get more text field after check this box.', 'third-eye'),
        'section'    => 'header_image',
        'settings'   => 'third_eye_header_img_show',
        'type'       => 'checkbox',
        'priority'       => 5,
    ));
     $wp_customize->add_setting('home_text', array(
     	'default' =>  '',
        'capability'     => 'edit_theme_options',
        'type'           => 'theme_mod',
        'sanitize_callback' => 'sanitize_text_field',
        'transport' => 'postMessage',
    ));
    $wp_customize->add_control('home_text_control', array(
        'label'      => __('Header image home title', 'third-eye'),
        'description'     => __('Enter your home image title here. The title only show in home page', 'third-eye'),
        'section'    => 'header_image',
        'settings'   => 'home_text',
        'type'       => 'textarea',
        'active_callback' => 'third_eye_banner_show_hide',

    ));

     $wp_customize->add_setting('home_subtext', array(
     	'default' =>  '',
        'capability'     => 'edit_theme_options',
        'type'           => 'theme_mod',
        'sanitize_callback' => 'sanitize_text_field',
        'transport' => 'postMessage',
    ));
    $wp_customize->add_control('home_subtext_control', array(
        'label'      => __('Header image home sub-title', 'third-eye'),
        'description'     => __('Enter your home image sub-title here. The sub-title only show in home page', 'third-eye'),
        'section'    => 'header_image',
        'settings'   => 'home_subtext',
        'type'       => 'textarea',
        'active_callback' => 'third_eye_banner_show_hide',
    ));
     $wp_customize->add_setting('animation_text_one', array(
     	'default' =>  '',
        'capability'     => 'edit_theme_options',
        'type'           => 'theme_mod',
        'sanitize_callback' => 'sanitize_text_field',
        'transport' => 'refresh',
    ));
    $wp_customize->add_control('animation_text_one_control', array(
        'label'      => __('Header animation text one', 'third-eye'),
        'description'     => __('Enter your home image sub-title animation text one here.', 'third-eye'),
        'section'    => 'header_image',
        'settings'   => 'animation_text_one',
        'type'       => 'text',
        'active_callback' => 'third_eye_banner_show_hide',
    ));
     $wp_customize->add_setting('animation_text_two', array(
     	'default' =>  '',
        'capability'     => 'edit_theme_options',
        'type'           => 'theme_mod',
        'sanitize_callback' => 'sanitize_text_field',
        'transport' => 'refresh',
    ));
    $wp_customize->add_control('animation_text_two_control', array(
        'label'      => __('Header animation text two', 'third-eye'),
        'description'     => __('Enter your home image sub-title animation text two here.', 'third-eye'),
        'section'    => 'header_image',
        'settings'   => 'animation_text_two',
        'type'       => 'text',
        'active_callback' => 'third_eye_banner_show_hide',
    ));
     $wp_customize->add_setting('animation_text_three', array(
        'capability'     => 'edit_theme_options',
        'type'           => 'theme_mod',
        'sanitize_callback' => 'sanitize_text_field',
        'transport' => 'refresh',
    ));
    $wp_customize->add_control('animation_text_three_control', array(
        'label'      => __('Header animation text three', 'third-eye'),
        'description'     => __('Enter your home image sub-title animation text three here.', 'third-eye'),
        'section'    => 'header_image',
        'settings'   => 'animation_text_three',
        'type'       => 'text',
        'active_callback' => 'third_eye_banner_show_hide',
    ));
     $wp_customize->add_setting('btn_text_one', array(
        'capability'     => 'edit_theme_options',
        'type'           => 'theme_mod',
        'sanitize_callback' => 'sanitize_text_field',
        'transport' => 'refresh',
    ));
    $wp_customize->add_control('btn_text_one_control', array(
        'label'      => __('Button one text', 'third-eye'),
        'description'     => __('Enter button one text.', 'third-eye'),
        'section'    => 'header_image',
        'settings'   => 'btn_text_one',
        'type'       => 'text',
        'active_callback' => 'third_eye_banner_show_hide',
    ));

     $wp_customize->add_setting('btn_url_one', array(
        'capability'     => 'edit_theme_options',
        'type'           => 'theme_mod',
        'sanitize_callback' => 'sanitize_text_field',
        'transport' => 'refresh',
    ));
    $wp_customize->add_control('btn_url_one_control', array(
        'label'      => __('Button one url', 'third-eye'),
        'description'     => __('Enter button one url.', 'third-eye'),
        'section'    => 'header_image',
        'settings'   => 'btn_url_one',
        'type'       => 'text',
        'active_callback' => 'third_eye_banner_show_hide',
    ));
     $wp_customize->add_setting('btn_text_two', array(
        'capability'     => 'edit_theme_options',
        'type'           => 'theme_mod',
        'sanitize_callback' => 'sanitize_text_field',
        'transport' => 'refresh',
    ));
    $wp_customize->add_control('btn_text_two_control', array(
        'label'      => __('Button two text', 'third-eye'),
        'description'     => __('Enter button two text.', 'third-eye'),
        'section'    => 'header_image',
        'settings'   => 'btn_text_two',
        'type'       => 'text',
        'active_callback' => 'third_eye_banner_show_hide',
    ));

     $wp_customize->add_setting('btn_url_two', array(
        'capability'     => 'edit_theme_options',
        'type'           => 'theme_mod',
        'sanitize_callback' => 'sanitize_text_field',
        'transport' => 'refresh',
    ));
    $wp_customize->add_control('btn_url_two_control', array(
        'label'      => __('Button two url', 'third-eye'),
        'description'     => __('Enter button two url.', 'third-eye'),
        'section'    => 'header_image',
        'settings'   => 'btn_url_two',
        'type'       => 'text',
        'active_callback' => 'third_eye_banner_show_hide',
    ));

    // Add third_eye side menu section
    $wp_customize->add_section('third_eye_post_section', array(
        'title' => __('Third Eye post', 'third-eye'),
        'capability'     => 'edit_theme_options',
        'description'     => __('Third eye post settings section.', 'third-eye'),

    ));

     $wp_customize->add_setting('thrid_eye_post_view', array(
        'default'       => 'list',
        'capability'     => 'edit_theme_options',
        'type'           => 'theme_mod',
        'sanitize_callback' => 'third_eye_sanitize_post_grid',
        'transport' => 'refresh',
    ));
    $wp_customize->add_control('third_eye_post_control', array(
        'label'      => __('Post view style', 'third-eye'),
        'section'    => 'third_eye_post_section',
        'settings'   => 'thrid_eye_post_view',
        'type'       => 'select',
        'choices'    => array(
            'grid' => __('Grid view', 'third-eye'),
            'list' => __('List view', 'third-eye'),
        ),
    ));


}
add_action( 'customize_register', 'third_eye_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function third_eye_customize_partial_blogname() {
	esc_html(bloginfo( 'name' ));
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function third_eye_customize_partial_blogdescription() {
	esc_html(bloginfo( 'description' ));
}

function third_eye_sanitize_post_grid($value){ 
    if(!in_array($value, array('grid','list'))){
        $value = 'list';
    }
    return $value;
}
function third_eye_banner_show_hide(){
    if (get_theme_mod('third_eye_header_img_show', 0) == 1) {
        return true;
    }else{
    return false;
    }

}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function third_eye_customize_preview_js() {
	wp_enqueue_script( 'third-eye-customizer', get_template_directory_uri() . '/assets/js/customizer.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'third_eye_customize_preview_js' );

function third_eye_notice__error() {
        
    if(get_option('third_eye')){
        return;
    }
    $class = 'eye-notice notice notice-warning is-dismissible';
    $message = __( '<strong><span style="color:red;">Good News For You!!:</span>  <span style="color:green">Pay One Time And Get License Life time!!.</span> So Hurry up get you pro theme now.<strong><span style="color:red;"> WordPress Pro Theme Now $21.</span><br> <strong style="color:blue">WordPress Pro Theme is more secure more SEO friendly and more user friendly.</strong> ', 'third-eye' );
    $url1 = esc_url('https://wpthemespace.com/product/eyepress-pro/');
    $url2 = esc_url('https://wpthemespace.com/product-category/theme/');
    $url3 = esc_url('https://www.youtube.com/watch?v=LXY_zVQOdTA&t=3s');

    printf( '<div class="%1$s" style="padding:10px 15px 20px;text-transform:uppercase"><p>%2$s</p><a target="_blank" class="button button-danger" href="%3$s" style="margin-right:10px">'.esc_html('EyePress Pro Theme').'</a><a target="_blank" class="button button-primary" href="%4$s">'.esc_html('Vew All Theme').'</a><a style="margin:0 10px" target="_blank" class="button button-primary" href="%5$s">'.esc_html('Show video').'</a><a class="eyehide" href="#">'.esc_html('Dismiss the notice').'</a></div>', esc_attr( $class ), wp_kses_post( $message ),$url2,$url1,$url3 ); 
}
add_action( 'admin_notices', 'third_eye_notice__error' );

function third_eye_notice_option(){
    if(isset($_GET['hnotice']) && $_GET['hnotice'] == 1 ){
        update_option( 'third_eye', 1);
    }
}
add_action('init','third_eye_notice_option');